# arpes.plotting.qt\_tool.AxisInfoWidget module

**class
arpes.plotting.qt\_tool.AxisInfoWidget.AxisInfoWidget(parent=None,
root=None, axis\_index=None)**

> Bases: `PyQt5.QtWidgets.QGroupBox`
> 
> **on\_transpose()**
> 
> **recompute()**
